@@ -10,13 +10,14 @@ from timepiece import models as timepiece
 
 class ProjectLookup(ModelLookup):
     model = timepiece.Project
-    search_fields = ('name__icontains',)
+    search_fields = ('name__icontains', 'business__name__icontains',
+            'business__short_name__icontains')
 registry.register(ProjectLookup)
 
 
 class BusinessLookup(ModelLookup):
     model = timepiece.Business
-    search_fields = ('name__icontains',)
+    search_fields = ('name__icontains', 'short_name__icontains')
 
     def get_item_label(self, business):
         return '<span class="business">%s</span>' % business.name
@@ -26,12 +27,8 @@ registry.register(BusinessLookup)
 
 class UserLookup(ModelLookup):
     model = auth_models.User
-    search_fields = (
-        'username__icontains',
-        'first_name__icontains',
-        'last_name__icontains',
-        'email__icontains'
-    )
+    search_fields = ('username__icontains', 'first_name__icontains',
+            'last_name__icontains', 'email__icontains')
 
     def format_result(self, user):
         """
@@ -39,7 +36,7 @@ class UserLookup(ModelLookup):
         may contain html and multi-lines
         """
         return u"<span class='%s'>%s</span>" % ('individual',
-            user.get_full_name())
+            user.get_name_or_username())
 
     def get_item_label(self, user):
         return self.format_result(user)
@@ -48,7 +45,7 @@ class UserLookup(ModelLookup):
         return user.pk
 
     def get_item_value(self, user):
-        return user.get_full_name()
+        return user.get_name_or_username()
 
 registry.register(UserLookup)
 
@@ -64,6 +61,7 @@ class SearchResult(object):
 
 
 class QuickLookup(LookupBase):
+
     def get_query(self, request, q):
         """
         return a query set (or a fake one).  you also have access to
@@ -74,11 +72,12 @@ class QuickLookup(LookupBase):
         users = auth_models.User.objects.filter(
             Q(first_name__icontains=q) |
             Q(last_name__icontains=q) |
+            Q(username__icontains=q) |
             Q(email__icontains=q)
         ).select_related().order_by('last_name')[:10]
 
         for user in users:
-            name = user.get_full_name()
+            name = user.get_name_or_username()
             results.append(
                 SearchResult(user.pk, 'individual', name)
             )
